/* Replication Code for Goplerud and Schleiter (2015) */

clear
est clear
set more off
/*	Set the appropriate working directory*/
/*cd ~/shared_space/mgoplerud/CPS_Analysis*/

use GS_Replication.dta

/*	Initial Scatterplots (Figure 1)	*/
label variable gr_an "Growth (Non-Benchmarked)"
label variable gr_loc_pc_an "Local Growth (PC)"
label variable gr_loc_med_an "Local Growth (Median)"
label variable unem_an "Unemployment (Non-Benchmarked)"
label variable gr_loc_tr_an "Local Growth (Trade)"
label variable unem_loc_pc_an "Local Unemployment (PC)"

levelsof v_pm_score, local(verbal_pm)
foreach i of var gr_loc_pc_an unem_loc_pc_an{
	foreach j in `verbal_pm'{
		quietly twoway (lfit votelead `i' if v_pm_score == "`j'", lwidth(thick)) (scatter votelead `i' if v_pm_score == "`j'", msymbol(circle_hollow) legend(off) scheme(s1mono) ytitle("Vote for Leader's Party") yscale(range(0(10)60)) ylabel(0(10)60) xscale(range(-10(5)10)) xlabel(-10(5)10)) 
		graph export `=strtoname("`i' and `j'")'.pdf, replace
	}
}


/*	Split Sample Regressions (Table 4)	*/
forval i = 0/1{
	quietly reg votelead gr_an unem_an if pm_strong == `i', robust
	eststo t1_`i'_non, title("No Benchmark")
	quietly tab country if e(sample)
	quietly estadd scalar n_cty = r(r)
	* column 2 *
	quietly reg votelead gr_loc_med_an gr_glob_med_an unem_loc_med_an unem_glob_med_an if pm_strong == `i', robust
	eststo t1_`i'_med, title("Median")
	quietly tab country if e(sample)
	quietly estadd scalar n_cty = r(r)
	* column 3 *
	quietly reg votelead gr_loc_pc_an gr_glob_pc_an unem_loc_pc_an unem_glob_pc_an if pm_strong == `i', robust
	eststo t1_`i'_pc, title("PC")
	quietly tab country if e(sample)
	quietly estadd scalar n_cty = r(r)
	* column 4 *
	quietly reg votelead gr_loc_tr_an gr_glob_tr_an unem_loc_tr_an unem_glob_tr_an if pm_strong == `i', robust
	eststo t1_`i'_trade, title("Trade")
	quietly tab country if e(sample)
	quietly estadd scalar n_cty = r(r)
}

#delimit ;
estout t1* using "table_4.tex",
cells(b(star fmt(2)) t(par fmt(2)))
rename(gr_loc_pc_an gr_loc_med_an
gr_loc_tr_an gr_loc_med_an
gr_glob_pc_an gr_glob_med_an
gr_glob_tr_an gr_glob_med_an
unem_loc_pc_an unem_loc_med_an
unem_loc_tr_an unem_loc_med_an
unem_glob_pc_an unem_glob_med_an
unem_glob_tr_an unem_glob_med_an
)
varlabel(gr_an "Growth"
unem_an "Unemployment"
gr_loc_med_an "Local Growth"
gr_glob_med_an "Global Growth"
unem_loc_med_an "Local Unemp."
unem_glob_med_an "Global Unemp."
_cons "Constant")
posthead(&(1)&(2)&(3)&(4)&(5)&(6)&(7)&(8)\\)
label
starlevel(\sym{*} 0.10 \sym{**} 0.05 \sym{***} 0.01)
style(tex)
replace
collab("",none)
stats(N n_cty, label("Number of Elections" "Number of Countries") fmt(0))
;
#delimit cr

/*	Create Figures for Time Windows	(Figure 2)*/
do "GS_Time.do"

/*	Three Way Interactions	(Table 5)*/
foreach i of var pm_strong joint_exec_strong{
	quietly reg votelead i.`i'##c.gr_loc_pc_an##c.unem_loc_pc_an gr_glob_pc_an unem_glob_pc_an, robust
	eststo three_`i'
}
foreach i of var diss_pm diss_joint_exec{
	quietly reg votelead c.`i'##c.gr_loc_pc_an##c.unem_loc_pc_an gr_glob_pc_an unem_glob_pc_an, robust
	eststo three_`i'
}

#delimit ;
estout three_* using "three_way_inter.tex",
replace
style(tex)
cells(b(star fmt(2)) t(par fmt(2)))
drop(0.*)
rename(1.joint_exec_strong 1.pm_strong
1.joint_exec_strong#c.gr_loc_pc_an 1.pm_strong#c.gr_loc_pc_an
1.joint_exec_strong#c.unem_loc_pc_an 1.pm_strong#c.unem_loc_pc_an
c.diss_pm#c.gr_loc_pc_an 1.pm_strong#c.gr_loc_pc_an 
c.diss_pm#c.unem_loc_pc_an 1.pm_strong#c.unem_loc_pc_an 
1.joint_exec_strong#c.gr_loc_pc_an#c.unem_loc_pc_an 1.pm_strong#c.gr_loc_pc_an#c.unem_loc_pc_an
c.diss_pm#c.gr_loc_pc_an#c.unem_loc_pc_an 1.pm_strong#c.gr_loc_pc_an#c.unem_loc_pc_an 
c.diss_joint_exec#c.gr_loc_pc_an#c.unem_loc_pc_an 1.pm_strong#c.gr_loc_pc_an#c.unem_loc_pc_an 
c.diss_joint_exec#c.gr_loc_pc_an 1.pm_strong#c.gr_loc_pc_an 
c.diss_joint_exec#c.unem_loc_pc_an 1.pm_strong#c.unem_loc_pc_an 
diss_joint_exec 1.pm_strong
diss_pm 1.pm_strong
)
varlabel(1.pm_strong "Dissolution Powers"
1.pm_strong#c.gr_loc_pc_an#c.unem_loc_pc_an "Power X Loc. Growth X Loc. Unemp"
gr_loc_pc_an "Local Growth (PC)"
unem_loc_pc_an "Local Unem. (PC)"
gr_glob_pc_an "Glob. Growth (PC)"
unem_glob_pc_an "Glob. Unemp. (PC)"
1.pm_strong#c.gr_loc_pc_an "Powers X Local Growth"
1.pm_strong#c.unem_loc_pc_an "Powers X Local Unemp."
c.gr_loc_pc_an#c.unem_loc_pc_an "Growth X Loc. Unemp"
_cons "Constant")
eqlabel("",none)
prefoot("N & \multicolumn{@M}{c}{213} \\") 
mlabel("PM" "Executive" "PM" "Executive")
posthead(&(1a)&(1b)&(2a)&(2b)\\)
collab("",none)
starlevel(\sym{*} 0.10 \sym{**} 0.05 \sym{***} 0.01)
;
#delimit cr

/* Visualise Marginal Effects: Figure 3 */
capture: drop r_*
estimates restore three_diss_pm
gen r_1 = -2 if e(sample)
gen r_symbol = "|"

margins, dydx(diss_pm) at(unem_loc_pc_an = (-7(1.5)12.5) gr_loc_pc_an = 0.2829)
marginsplot, recastci(rarea) title("") yline(0) legend(off) addplot(scatter r_1 unem_loc_pc_an, msymbol(none) mlabel(r_symbol) xlabel(-7(1.5)12.5)) scheme(s1mono)
graph export me_diss_vary_unem.pdf, replace

estimates restore three_diss_pm
gen r_2 = -1.25 if e(sample)

margins, dydx(diss_pm) at(gr_loc_pc_an = (-7(1.5)9.5) unem_loc_pc_an = 0.1832)
marginsplot, recastci(rarea) title("") yline(0) legend(off) addplot(scatter r_2 gr_loc_pc_an, msymbol(none) mlabel(r_symbol) xlabel(-7(1.5)9.5)) scheme(s1mono)
graph export me_diss_vary_gr.pdf, replace


/*In Text Statistics*/
estimates restore three_joint_exec_strong
margins, dydx(joint_exec_strong) at(gr_loc_pc_an = 0.2829 unem_loc_pc_an = 0.1832) post
scalar mean_gov = _b[1.joint_exec_strong]

estimates restore three_pm_strong
margins, dydx(pm_strong) at(gr_loc_pc_an = 0.2829 unem_loc_pc_an = 0.1832) post
scalar mean_pm = _b[1.pm_strong]

di mean_pm-mean_gov

/*Figures in SI 3*/
capture: drop r_*
estimates restore three_diss_pm

margins, dydx(gr_loc_pc_an) at(diss_pm = (0(1)10) unem_loc_pc_an = 0.1832)
marginsplot, recastci(rarea) yline(0) scheme(s1mono) title("") xtitle("PM Dissolution Power")
graph export me_gr.pdf, replace

margins, dydx(unem_loc_pc_an) at(diss_pm = (0(1)10) gr_loc_pc_an = 0.2829)
marginsplot, recastci(rarea) yline(0) scheme(s1mono) title("") xtitle("PM Dissolution Power")
graph export me_un.pdf, replace
